## Reporting Security Vulnerabilities

**We urge you not to file a bug report in the GitHub issue tracker, since they are open for anyone to see**

Instead, we encourage you to reach out to the maintainer team so we can assess the problem and later disclose it
responsibly.

To do so, you can use the `Security` tab and file a bug report there
![image](https://user-images.githubusercontent.com/20902250/209860003-573a5219-5e71-4f27-91ec-7ad6c0516749.png)

Alternatively, you can also reach out to the maintainer team directly. If you prefer this approach, you can contact one
of the people below:

- **ItsDrike** (project maintainer and owner)
    - **Email:** `itsdrike@protonmail.com`
    - **Discord:** `ItsDrike` (however you will need to join the [py-mine discord](https://discord.gg/C2wX7zduxC) too,
        as I might not answer to message requests from people I don't share a server with.)
